@@ -1,5 +1,5 @@
 is.GNARnet <- function(x){
-  results <- vector(mode="logical", length=7)
+  results <- vector(mode="logical", length=9)
   results[1] <- is.list(x)
   results[2] <- all(names(x) == c("edges", "dist"))
   results[3] <- length(x$edges)==length(x$dist)
@@ -9,6 +9,13 @@ is.GNARnet <- function(x){
     results[5] <- all(unlist(x$edges)%in%tmp2)
     results[6] <- class(x) == "GNARnet"
     results[7] <- all(sapply(x$edges, length)==sapply(lapply(x$edges, unique), length))
+    results[8] <- all(unlist(x$dist)>0)
+  }
+  if(sum(results)==8){
+    selfloop <- function(n){
+      return(n %in% x$edges[[n]])
+    }
+    results[9] <- all(sapply(tmp2, selfloop)==FALSE)
   }
   return(all(results))
 }
